@@ -2,6 +2,9 @@
 
 namespace SimpleSAML\Module\saml\Auth\Process;
 
+use SimpleSAML\Error;
+use SimpleSAML\Logger;
+
 /**
  * Authentication processing filter to create a NameID from an attribute.
  *
@@ -24,7 +27,7 @@ class AttributeNameID extends \SimpleSAML\Module\saml\BaseNameIDGenerator
      * @param array $config Configuration information about this filter.
      * @param mixed $reserved For future use.
      *
-     * @throws \SimpleSAMLError\Exception If the required options 'Format' or 'attribute' are missing.
+     * @throws \SimpleSAML\Error\Exception If the required options 'Format' or 'attribute' are missing.
      */
     public function __construct($config, $reserved)
     {
@@ -32,12 +35,12 @@ class AttributeNameID extends \SimpleSAML\Module\saml\BaseNameIDGenerator
         assert(is_array($config));
 
         if (!isset($config['Format'])) {
-            throw new \SimpleSAML\Error\Exception("AttributeNameID: Missing required option 'Format'.");
+            throw new Error\Exception("AttributeNameID: Missing required option 'Format'.");
         }
         $this->format = (string) $config['Format'];
 
         if (!isset($config['attribute'])) {
-            throw new \SimpleSAML\Error\Exception("AttributeNameID: Missing required option 'attribute'.");
+            throw new Error\Exception("AttributeNameID: Missing required option 'attribute'.");
         }
         $this->attribute = (string) $config['attribute'];
     }
@@ -51,28 +54,27 @@ class AttributeNameID extends \SimpleSAML\Module\saml\BaseNameIDGenerator
      */
     protected function getValue(array &$state)
     {
-
         if (!isset($state['Attributes'][$this->attribute]) || count($state['Attributes'][$this->attribute]) === 0) {
-            \SimpleSAML\Logger::warning(
-                'Missing attribute '.var_export($this->attribute, true).
+            Logger::warning(
+                'Missing attribute ' . var_export($this->attribute, true) .
                 ' on user - not generating attribute NameID.'
             );
             return null;
         }
         if (count($state['Attributes'][$this->attribute]) > 1) {
-            \SimpleSAML\Logger::warning(
-                'More than one value in attribute '.var_export($this->attribute, true).
+            Logger::warning(
+                'More than one value in attribute ' . var_export($this->attribute, true) .
                 ' on user - not generating attribute NameID.'
             );
             return null;
         }
         $value = array_values($state['Attributes'][$this->attribute]); // just in case the first index is no longer 0
-        $value = $value[0];
+        $value = strval($value[0]);
 
         if (empty($value)) {
-            \SimpleSAML\Logger::warning(
-                'Empty value in attribute '.var_export($this->attribute, true).
-                ' on user - not generating persistent NameID.'
+            Logger::warning(
+                'Empty value in attribute ' . var_export($this->attribute, true) .
+                ' on user - not generating attribute NameID.'
             );
             return null;
         }
